#ifndef GRACE_H
#define GRACE_H

#include <string>
#include <CurvePlotter.h>
#include "Region.h"

class Grace : public CurvePlotter {
public:

	Grace(const std::string &s = "");

    void readSets(const std::string &);
    void writeSet(int setNr, const std::string &fileName) const;
	bool isUp() const;
    void killAll();
    void killSet(int);
	std::vector<std::string> regionSelection() const;

	static GeoRegion toRegion(const std::vector<std::string> &regionSpec);
		//
		//	PURPOSE:
		//		Convert a string vector with region specifications into
		//		a <GeoRegion> object
		//
		//	ARGUMENTS:
		//		regionSpec: vector with regions specification strings
		//					in Grace format, e.g.
		//					"type below; line 0.3369, 0.7754, 0.5803, 0.7334"
		//
		//	RETURNS:
		//		Region object corresponding to given <regionSpec> string;
		//		all elements are packed into one Component
		//			

	~Grace();

private:
	void getRegions(const std::string &paramfile, std::vector<std::string>&)
	const;
	enum RegionType { NONE = -1,
					  ABOVE_LINE, BELOW_LINE,
					  LEFT_OF_LINE, RIGHT_OF_LINE,
					  IN_HORIZ_RANGE, OUT_HORIZ_RANGE,
					  IN_VERTI_RANGE, OUT_VERTI_RANGE,
					  INSIDE_POLY, OUTSIDE_POLY };
	static RegionType type(const std::vector<std::string> &comp);
};

#endif
