//-----------------------------------------------------------------------------
//
//                      XMM Science Analysis System (SAS)
//                     (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	dsplot.cc	--- xy-plotting task
//
//	DESCROPTION:
//		A task subroutines that plots a table in a data set using
//		the third-party plotting program grace.
//
//	CHANGE HISTORY:
//		MB, 1999-??-??: 1.0.0: - first version
//		UL, 1999-10-25: 1.1.0: - added "withscatterplot" parameter
//							   - added "withoffsetx" parameter
//		UL, 2003-01-17: 1.2.0: - added various parameters related to
//								 new abscissa data range plotting facility
//		UL, 2003-03-14: 1.3.0: - added parameters
//									o withalltablesafter
//									o subtitle
//
//	AUTHORS:
//		Marco Beijersbergen (MB)
//		Uwe Lammers (UL)
//
//	$Header: /sasbuild/repositories/sasdev/sas/packages/dsplot/src/dsplot.cc,v 1.15 2008/09/29 16:04:10 cgabriel Exp $
//
#include <cstdio>	// C
#include <cstdlib>
#include <unistd.h>

#include <fstream>	// C++

#include "errstr.h"	// SAS
#include "param.h"
#include "metatask.h"

#include "dstoplot.h"
#include "dsplot.h"

using namespace std;

void dsplot()
{
	ParameterInfo &i = *Info::Task::current()->parameters();
	Info::Task *o = task("dstoplot");

	string plotter = i["plotter"]->stringValue();

	char *tmpName = tempnam(0, "dspl");

	o->setParameter("withtable", i["withtable"]->boolValue());
	o->setParameter("table", i["table"]->stringValue());
	o->setParameter("index", i["index"]->boolValue());
	o->setParameter("title", i["title"]->stringValue());
	o->setParameter("subtitle", i["subtitle"]->stringValue());
	o->setParameter("withx", i["withx"]->boolValue());
	o->setParameter("x", i["x"]->stringValue());
	o->setParameter("withoffsetx", i["withoffsetx"]->boolValue());
	o->setParameter("withxmin", i["withxmin"]->boolValue());
	o->setParameter("xmin", i["xmin"]->realValue());
	o->setParameter("withxmax", i["withxmax"]->boolValue());
	o->setParameter("xmax", i["xmax"]->realValue());
	o->setParameter("withymin", i["withymin"]->boolValue());
	o->setParameter("ymin", i["ymin"]->realValue());
	o->setParameter("withymax", i["withymax"]->boolValue());
	o->setParameter("ymax", i["ymax"]->realValue());
	o->setParameter("xlog", i["xlog"]->boolValue());
	o->setParameter("ylog", i["ylog"]->boolValue());

	o->setParameter("withy", i["withy"]->boolValue());
	o->setParameter("y", i["y"]->stringListValue());
	o->setParameter("output", "file");
	o->setParameter("outputfile", tmpName);
	o->setParameter("withscatter", i["withscatter"]->boolValue());
	o->setParameter("setsymbols", i["setsymbols"]->intListValue());
	o->setParameter("setcolors", i["setcolors"]->intListValue());

	o->setParameter("withxranges", i["withxranges"]->boolValue());
	o->setParameter("xrangetables", i["xrangetables"]->stringListValue());
	o->setParameter("withalltablesafter",i["withalltablesafter"]->boolValue());
	o->setParameter("xrangefromcol", i["xrangefromcol"]->stringValue());
	o->setParameter("xrangetocol", i["xrangetocol"]->stringValue());
	o->setParameter("withybase", i["withybase"]->boolValue());
	o->setParameter("ybase", i["ybase"]->realValue());
	o->setParameter("withystride", i["withystride"]->boolValue());
	o->setParameter("ystride", i["ystride"]->realValue());

	o->exec();

        string print = "";

        if( i["tofile"]->boolValue() ) {
          print = " -hardcopy -printfile " + i["file"]->stringValue() + " ";
        }
 

	string command = plotter + string(" -nosafe -noask  ") + print + tmpName;
	system(command.c_str());

	unlink(tmpName);

	free(tmpName);
}
